==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebGridTemplateContextDescription } from "./WebGridTemplateContextDescription";
/**
 * @hidden
 */
var WebGridTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridTemplateContextDescriptionMetadata, _super);
    function WebGridTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridTemplateContextDescriptionMetadata.a == null) {
            WebGridTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridTemplateContextDescriptionMetadata.c(WebGridTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebGridTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridTemplateContextDescriptionMetadata.a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebGridTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "ExportedType:WebGridBaseDirective");
    };
    WebGridTemplateContextDescriptionMetadata.d = function (a) {
        WebGridTemplateContextDescriptionMetadata.b(a);
        a.aa("WebGridTemplateContext", function () { return new WebGridTemplateContextDescription(); });
        a.z("WebGridTemplateContext", WebGridTemplateContextDescriptionMetadata.a);
    };
    WebGridTemplateContextDescriptionMetadata.$t = markType(WebGridTemplateContextDescriptionMetadata, 'WebGridTemplateContextDescriptionMetadata');
    WebGridTemplateContextDescriptionMetadata.a = null;
    return WebGridTemplateContextDescriptionMetadata;
}(Base));
export { WebGridTemplateContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebGridTemplateContextDescription } from "./WebGridTemplateContextDescription";
/**
 * @hidden
 */
var WebGridTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridTemplateContextDescriptionMetadata, _super);
    function WebGridTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridTemplateContextDescriptionMetadata.a == null) {
            WebGridTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridTemplateContextDescriptionMetadata.c(WebGridTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridTemplateContextDescriptionMetadata.a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebGridTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebGridBaseDirective");
    };
    WebGridTemplateContextDescriptionMetadata.d = function (a) {
        WebGridTemplateContextDescriptionMetadata.b(a);
        a.ac("WebGridTemplateContext", function () { return new WebGridTemplateContextDescription(); });
        a.ab("WebGridTemplateContext", WebGridTemplateContextDescriptionMetadata.a);
    };
    WebGridTemplateContextDescriptionMetadata.$t = markType(WebGridTemplateContextDescriptionMetadata, 'WebGridTemplateContextDescriptionMetadata');
    WebGridTemplateContextDescriptionMetadata.a = null;
    return WebGridTemplateContextDescriptionMetadata;
}(Base));
export { WebGridTemplateContextDescriptionMetadata };
